==> kaf-pas-0.0.120.tar.gz: kaf-pas-0.0.120/kaf_pas/common/models/__init__.py <==
class GridCoonstant:
    refresh_production_order_grid = "refresh_production_order_grid"
    refresh_production_order_grid_row = "refresh_production_order_grid_row"

    refresh_operationsGrid = "operationsGrid"
    refresh_operationsGrid_row = "operationsGridRow"

    refresh_production_order_item_grid = "refresh_production_order_item_grid"
    refresh_production_order_item_grid_row = "refresh_production_order_item_gridRow"

    refresh_production_operations_grid = "refresh_production_operations_grid"
    refresh_production_operations_grid_row = "refresh_production_operations_grid_grid_row"

    refresh_production_order_operationsValues_grid = "refresh_production_order_operationsValues_grid"
    refresh_production_order_operationsValues_grid_row = "refresh_production_order_operationsValues_grid_row"

    refresh_production_launch_grid = "refresh_production_launch_grid"
    refresh_production_launch_grid_row = "refresh_production_launch_grid_row"

    refresh_production_buffers_grid = "refresh_production_buffers_grid"
    refresh_production_buffers_grid_row = "refresh_production_buffers_grid_row"

    refresh_item_view_grid = "refresh_item_view_grid"
    refresh_item_view_grid_row = "refresh_item_view_grid_row"

    refresh_item_variant_view_grid = "refresh_item_variant_view_grid"
    refresh_item_variant_view_grid_row = "refresh_item_variant_view_grid_row"

    tmp_operation_value_view_grid = "tmp_operation_value_view_grid"
    tmp_operation_value_view_grid_row = "tmp_operation_value_view_grid_row"

    lock_insert_update_delete_function_of_table = "lock_insert_update_delete_function_of_table"

    refresh_uploades_documents_grid = "refresh_uploades_documents_grid"
    refresh_uploades_documents_grid_row = "refresh_uploades_documents_grid_row"

    refresh_upload_logs_grid = "refresh_upload_logs_grid";
    refresh_upload_logs_grid_row = "refresh_upload_logs_grid_row";

==> kaf-pas-0.0.121.tar.gz: kaf-pas-0.0.121/kaf_pas/common/models/__init__.py <==
class GridCoonstant:

    refresh_production_order_grid = "refresh_production_order_grid"
    refresh_production_order_grid_row = "refresh_production_order_grid_row"

    refresh_production_order_tmp_grid = "refresh_production_order_tmp_grid"
    refresh_production_order_tmp_grid_row = "refresh_production_order_tmp_grid_row"

    refresh_ItemRefsr_grid = "refresh_ItemRefsr_grid"
    refresh_ItemRefs_grid_row = "refresh_ItemRefs_grid_row"

    refresh_operationsGrid = "operationsGrid"
    refresh_operationsGrid_row = "operationsGridRow"

    refresh_production_order_item_grid = "refresh_production_order_item_grid"
    refresh_production_order_item_grid_row = "refresh_production_order_item_gridRow"

    refresh_production_operations_grid = "refresh_production_operations_grid"
    refresh_production_operations_grid_row = "refresh_production_operations_grid_row"

    refresh_production_order_operationsValues_grid = "refresh_production_order_operationsValues_grid"
    refresh_production_order_operationsValues_grid_row = "refresh_production_order_operationsValues_grid_row"

    refresh_production_launch_grid = "refresh_production_launch_grid"
    refresh_production_launch_grid_row = "refresh_production_launch_grid_row"

    refresh_production_buffers_grid = "refresh_production_buffers_grid"
    refresh_production_buffers_grid_row = "refresh_production_buffers_grid_row"

    refresh_item_view_grid = "refresh_item_view_grid"
    refresh_item_view_grid_row = "refresh_item_view_grid_row"

    refresh_item_variant_view_grid = "refresh_item_variant_view_grid"
    refresh_item_variant_view_grid_row = "refresh_item_variant_view_grid_row"

    tmp_operation_value_view_grid = "tmp_operation_value_view_grid"
    tmp_operation_value_view_grid_row = "tmp_operation_value_view_grid_row"

    lock_insert_update_delete_function_of_table = "lock_insert_update_delete_function_of_table"

    refresh_uploades_documents_grid = "refresh_uploades_documents_grid"
    refresh_uploades_documents_grid_row = "refresh_uploades_documents_grid_row"

    refresh_upload_logs_grid = "refresh_upload_logs_grid"
    refresh_upload_logs_grid_row = "refresh_upload_logs_grid_row"

    refresh_ProductionOrderMadeHistory_grid = "refresh_ProductionOrderMadeHistory_grid"
    refresh_ProductionOrderMadeHistory_grouped_grid = "refresh_ProductionOrderMadeHistory_grouped_grid"
